@@ -2,7 +2,7 @@
   FILE: icalcomponent.c
   CREATOR: eric 28 April 1999
   
-  $Id: icalcomponent.c 21010 2006-04-16 14:39:54Z benny $
+  $Id$
 
  (C) COPYRIGHT 2000, Eric Busboom, http://www.softwarestudio.org
 
@@ -96,7 +96,7 @@ void icalcomponent_add_children(icalcomponent *impl, va_list args)
 {
     void* vp;
     
-    while((vp = va_arg(args, void*)) != 0) {
+    while((vp = va_arg(args, void*)) != NULL) {
 
 	assert (icalcomponent_isa_component(vp) != 0 ||
 		icalproperty_isa_property(vp) != 0 ) ;
@@ -155,8 +155,8 @@ icalcomponent_vanew (icalcomponent_kind kind, ...)
 
    icalcomponent *impl = icalcomponent_new_impl(kind);
 
-    if (impl == 0){
-	return 0;
+    if (impl == NULL){
+	return NULL;
     }
 
    va_start(args,kind);
